RAG Pipeline
============

Vector store, embedding providers, and graph-expanded semantic search.

.. automodule:: curate_ipsum.rag
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.rag.vector_store
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.rag.embedding_provider
   :members:
   :show-inheritance:

.. automodule:: curate_ipsum.rag.search
   :members:
   :show-inheritance:
